from . import *


def main():
    import sys
    if len(sys.argv[1:]) != 2:
        exit(1)
    from base64 import b64decode
    key = b64decode(sys.argv[1])
    content = sys.argv[2]
    if b"PUBLIC KEY" in key:
        p(EasyRSA(public_key=key.encode("utf-8")).encrypt(content))
    elif b"PRIVATE KEY" in key:
        p(EasyRSA(private_key=key.encode("utf-8")).decrypt(content))
    else:
        exit(1)
    exit(0)


if __name__ == "__main__":
    main()



from setuptools import setup
from importlib import import_module
import os
import re


name = os.path.basename(os.path.dirname(os.path.abspath(__file__)))
locals()[name] = import_module(name)
readme = open("README.md").read()
description = re.search(r"<i>(.*?)</i>", readme)[1]
setup(
    name="easyrsa",
    version=locals()[name].version,
    keywords=locals()[name].keywords,
    packages=[name],
    url="https://github.com/foxe6-temp/easyrsa",
    license="AGPL-3.0",
    author="f̣ộx̣ệ6",
    author_email="foxe6@protonmail.com",
    description=description,
    long_description=readme,
    long_description_content_type="text/markdown",
    install_requires=open("requirements.txt").read().splitlines(),
    python_requires=">=3.7",
    entry_points = dict(console_scripts=[name+"="+name+"."+locals()[name].entry])
)



from Crypto.PublicKey import RSA
from Crypto.Cipher import PKCS1_OAEP
from omnitools import *


__ALL__ = ["EasyRSA"]


class EasyRSA(object):
    def __init__(self, bits: int = None, public_key: bytes = None, private_key: bytes = None) -> None:
        self.key = bits
        if self.key is not None:
            self.key = RSA.generate(bits=self.key)
        self.public_key = public_key
        self.private_key = private_key

    def gen_private_key(self, key_pair: key_pair_format):
        if self.public_key is None and self.private_key is None:
            key_pair["private_key"] = self.key.export_key()
        return self

    def gen_public_key(self, key_pair: key_pair_format):
        if self.public_key is None and self.private_key is None:
            key_pair["public_key"] = self.key.publickey().export_key()
        return self

    def encrypt(self, v: str_or_bytes) -> bytes:
        if self.key is None and self.private_key is None:
            if isinstance(v, str):
                try:
                    from base64 import b64decode
                    v = b64decode(v)
                except:
                    v = v.encode()
            return PKCS1_OAEP.new(RSA.import_key(self.public_key)).encrypt(v)

    def decrypt(self, v: str_or_bytes) -> str_or_bytes:
        if self.public_key is None and self.key is None:
            if isinstance(v, str):
                try:
                    from base64 import b64decode
                    v = b64decode(v)
                except:
                    pass
            v = PKCS1_OAEP.new(RSA.import_key(self.private_key)).decrypt(v)
            try:
                return v.decode()
            except UnicodeDecodeError:
                return v

